summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit5388d67e65c492d2f6d97eb8c38cd33e75b41fe6 (patch)
tree39d3e3dc656c66a47b99b65a6694492d11c1fdcb
parent433d7678bdd8a16b72df8a9bf7f7762bcdcc5412 (diff)
downloadyakuake-5388d67e65c492d2f6d97eb8c38cd33e75b41fe6.tar.gz
yakuake-5388d67e65c492d2f6d97eb8c38cd33e75b41fe6.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/yakuake@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
-rw-r--r--yakuake/src/first_run_dialog.cpp4
-rw-r--r--yakuake/src/first_run_dialog.h2
-rw-r--r--yakuake/src/general_settings.cpp4
-rw-r--r--yakuake/src/general_settings.h2
-rw-r--r--yakuake/src/image_button.cpp8
-rw-r--r--yakuake/src/image_button.h8
-rw-r--r--yakuake/src/main_window.cpp14
-rw-r--r--yakuake/src/main_window.h2
-rw-r--r--yakuake/src/session.cpp12
-rw-r--r--yakuake/src/session.h4
-rw-r--r--yakuake/src/skin_list_item.cpp4
-rw-r--r--yakuake/src/skin_list_item.h2
-rw-r--r--yakuake/src/skin_settings.cpp4
-rw-r--r--yakuake/src/skin_settings.h2
-rw-r--r--yakuake/src/tab_bar.cpp4
-rw-r--r--yakuake/src/tab_bar.h2
-rw-r--r--yakuake/src/tabbed_widget.cpp26
-rw-r--r--yakuake/src/tabbed_widget.h2
-rw-r--r--yakuake/src/terminal.cpp4
-rw-r--r--yakuake/src/terminal.h2
-rw-r--r--yakuake/src/terminal_focus_watcher.cpp4
-rw-r--r--yakuake/src/terminal_focus_watcher.h2
-rw-r--r--yakuake/src/terminal_splitter.cpp4
-rw-r--r--yakuake/src/terminal_splitter.h2
-rw-r--r--yakuake/src/title_bar.cpp20
-rw-r--r--yakuake/src/title_bar.h6
-rw-r--r--yakuake/src/translucent_widget.cpp2
-rw-r--r--yakuake/src/translucent_widget.h2
28 files changed, 77 insertions, 77 deletions
diff --git a/yakuake/src/first_run_dialog.cpp b/yakuake/src/first_run_dialog.cpp
index 6031873..62baf17 100644
--- a/yakuake/src/first_run_dialog.cpp
+++ b/yakuake/src/first_run_dialog.cpp
@@ -18,8 +18,8 @@
#include <kkeydialog.h>
-FirstRunDialog::FirstRunDialog(TQWidget* tqparent, const char* name)
- : FirstRunDialogUI(tqparent, name)
+FirstRunDialog::FirstRunDialog(TQWidget* parent, const char* name)
+ : FirstRunDialogUI(parent, name)
{
connect(key_button, TQT_SIGNAL(capturedShortcut(const KShortcut&)),
this, TQT_SLOT(validateShortcut(const KShortcut&)));
diff --git a/yakuake/src/first_run_dialog.h b/yakuake/src/first_run_dialog.h
index b026610..aab7ef7 100644
--- a/yakuake/src/first_run_dialog.h
+++ b/yakuake/src/first_run_dialog.h
@@ -25,7 +25,7 @@ class FirstRunDialog : public FirstRunDialogUI
TQ_OBJECT
public:
- explicit FirstRunDialog(TQWidget* tqparent, const char* name=NULL);
+ explicit FirstRunDialog(TQWidget* parent, const char* name=NULL);
~FirstRunDialog();
KShortcut shortcut();
diff --git a/yakuake/src/general_settings.cpp b/yakuake/src/general_settings.cpp
index 0acf03b..a1d1f03 100644
--- a/yakuake/src/general_settings.cpp
+++ b/yakuake/src/general_settings.cpp
@@ -23,8 +23,8 @@
#include <klocale.h>
-GeneralSettings::GeneralSettings(TQWidget* tqparent, const char* name)
- : GeneralSettingsUI(tqparent, name)
+GeneralSettings::GeneralSettings(TQWidget* parent, const char* name)
+ : GeneralSettingsUI(parent, name)
{
kcfg_width->setSuffix("%");
kcfg_height->setSuffix("%");
diff --git a/yakuake/src/general_settings.h b/yakuake/src/general_settings.h
index 38f66e5..304e4ab 100644
--- a/yakuake/src/general_settings.h
+++ b/yakuake/src/general_settings.h
@@ -23,7 +23,7 @@ class GeneralSettings : public GeneralSettingsUI
TQ_OBJECT
public:
- explicit GeneralSettings(TQWidget* tqparent, const char* name=NULL);
+ explicit GeneralSettings(TQWidget* parent, const char* name=NULL);
~GeneralSettings();
diff --git a/yakuake/src/image_button.cpp b/yakuake/src/image_button.cpp
index e0b4c95..c9b866d 100644
--- a/yakuake/src/image_button.cpp
+++ b/yakuake/src/image_button.cpp
@@ -21,7 +21,7 @@
#include <kglobalsettings.h>
-ImageButton::ImageButton(TQWidget* tqparent, const char* name, bool translucency) : TranslucentWidget(tqparent, name, translucency)
+ImageButton::ImageButton(TQWidget* parent, const char* name, bool translucency) : TranslucentWidget(parent, name, translucency)
{
state = 0;
toggle = false;
@@ -71,14 +71,14 @@ void ImageButton::showPopupMenu()
popup_menu->exec(mapToGlobal(TQPoint(0, height())));
}
-void ImageButton::setUpPixmap(const TQString& path, bool use_alpha_tqmask)
+void ImageButton::setUpPixmap(const TQString& path, bool use_alpha_mask)
{
up_pixmap.load(path);
resize(up_pixmap.size());
- if (up_pixmap.hasAlphaChannel()) setMask(*up_pixmap.tqmask());
+ if (up_pixmap.hasAlphaChannel()) setMask(*up_pixmap.mask());
- if (use_alpha_tqmask)
+ if (use_alpha_mask)
setUseTranslucency(true);
else
setMask(TQRegion(up_pixmap.rect()));
diff --git a/yakuake/src/image_button.h b/yakuake/src/image_button.h
index e852c9e..800c152 100644
--- a/yakuake/src/image_button.h
+++ b/yakuake/src/image_button.h
@@ -34,7 +34,7 @@ class ImageButton : public TranslucentWidget
TQ_OBJECT
public:
- explicit ImageButton(TQWidget* tqparent = 0, const char* name = 0, bool translucency = false);
+ explicit ImageButton(TQWidget* parent = 0, const char* name = 0, bool translucency = false);
~ImageButton();
/* Creates a toggle button */
@@ -46,7 +46,7 @@ class ImageButton : public TranslucentWidget
void setDelayedPopup(bool delay) { delay_popup = delay; }
/* Sets the widget's pixmaps */
- void setUpPixmap(const TQString& path, bool use_alpha_tqmask = false);
+ void setUpPixmap(const TQString& path, bool use_alpha_mask = false);
void setOverPixmap(const TQString& path);
void setDownPixmap(const TQString& path);
@@ -74,8 +74,8 @@ class ImageButton : public TranslucentWidget
TQTimer* popup_timer;
- /* Widget's tqmask */
- TQRegion tqmask;
+ /* Widget's mask */
+ TQRegion mask;
/* Widget's tip */
TQString tooltip;
diff --git a/yakuake/src/main_window.cpp b/yakuake/src/main_window.cpp
index b284dec..7f3a8b8 100644
--- a/yakuake/src/main_window.cpp
+++ b/yakuake/src/main_window.cpp
@@ -30,9 +30,9 @@
#include <kwin.h>
#include <dcopref.h>
-MainWindow::MainWindow(TQWidget * tqparent, const char * name) :
+MainWindow::MainWindow(TQWidget * parent, const char * name) :
DCOPObject("DCOPInterface"),
- KMainWindow(tqparent, name, TQt::WStyle_Customize | TQt::WStyle_NoBorder),
+ KMainWindow(parent, name, TQt::WStyle_Customize | TQt::WStyle_NoBorder),
step(0)
{
first_run_dialog = 0;
@@ -312,12 +312,12 @@ bool MainWindow::queryClose()
void MainWindow::updateWindowMask()
{
- TQRegion tqmask = title_bar->getWidgetMask();
+ TQRegion mask = title_bar->getWidgetMask();
- tqmask.translate(0, mask_height);
- tqmask += TQRegion(0, 0, width(), mask_height);
+ mask.translate(0, mask_height);
+ mask += TQRegion(0, 0, width(), mask_height);
- setMask(tqmask);
+ setMask(mask);
}
void MainWindow::showPopup(const TQString& text, int time)
@@ -1047,7 +1047,7 @@ void MainWindow::slotUpdateSize(int new_width, int new_height, int new_location)
back_widget->setGeometry(0, 0, width(), height());
- // Update the window tqmask.
+ // Update the window mask.
mask_height = (isVisible()) ? max_height : 0;
updateWindowMask();
}
diff --git a/yakuake/src/main_window.h b/yakuake/src/main_window.h
index 5483f5b..ec00461 100644
--- a/yakuake/src/main_window.h
+++ b/yakuake/src/main_window.h
@@ -54,7 +54,7 @@ class MainWindow : public KMainWindow, virtual public DCOPInterface
TQ_OBJECT
public:
- explicit MainWindow(TQWidget* tqparent = 0, const char* name = 0);
+ explicit MainWindow(TQWidget* parent = 0, const char* name = 0);
~MainWindow();
int selectedSession();
diff --git a/yakuake/src/session.h b/yakuake/src/session.h
index 1380a17..48528c4 100644
--- a/yakuake/src/session.h
+++ b/yakuake/src/session.h
@@ -31,7 +31,7 @@ class Session : public TQObject
public:
enum SessionType { Single, TwoHorizontal, TwoVertical, Quad };
- explicit Session(TQWidget* tqparent = 0, SessionType type = Single, const char* name = 0);
+ explicit Session(TQWidget* parent = 0, SessionType type = Single, const char* name = 0);
virtual ~Session();
int id() { return session_id; }
@@ -80,7 +80,7 @@ class Session : public TQObject
private:
void createInitialSplits(SessionType);
void split(TQWidget* active_terminal, Qt::Orientation o);
- Terminal* addTerminal(TQWidget* tqparent);
+ Terminal* addTerminal(TQWidget* parent);
bool checkFocusWidget();
static int available_session_id;
diff --git a/yakuake/src/skin_list_item.cpp b/yakuake/src/skin_list_item.cpp
index 8bfb6ad..d6359dd 100644
--- a/yakuake/src/skin_list_item.cpp
+++ b/yakuake/src/skin_list_item.cpp
@@ -22,9 +22,9 @@
#include <klocale.h>
-SkinListItem::SkinListItem(KListView* tqparent, const TQString& fancy_name,
+SkinListItem::SkinListItem(KListView* parent, const TQString& fancy_name,
const TQString& author, const TQPixmap& icon, const TQString& name, const TQString& dir)
- : KListViewItem(tqparent, fancy_name)
+ : KListViewItem(parent, fancy_name)
{
setName(name);
setAuthor(author);
diff --git a/yakuake/src/skin_list_item.h b/yakuake/src/skin_list_item.h
index 1b22981..8f06ddc 100644
--- a/yakuake/src/skin_list_item.h
+++ b/yakuake/src/skin_list_item.h
@@ -25,7 +25,7 @@ class TQSimpleRichText;
class SkinListItem : public KListViewItem
{
public:
- explicit SkinListItem(KListView* tqparent, const TQString& fancy_name,
+ explicit SkinListItem(KListView* parent, const TQString& fancy_name,
const TQString& author, const TQPixmap& icon, const TQString& name, const TQString& dir);
~SkinListItem();
diff --git a/yakuake/src/skin_settings.cpp b/yakuake/src/skin_settings.cpp
index 8b76e3a..8bdb79d 100644
--- a/yakuake/src/skin_settings.cpp
+++ b/yakuake/src/skin_settings.cpp
@@ -40,8 +40,8 @@
#include <unistd.h> // unlink()
-SkinSettings::SkinSettings(TQWidget* tqparent, const char* name, bool translucency)
- : SkinSettingsUI(tqparent, name)
+SkinSettings::SkinSettings(TQWidget* parent, const char* name, bool translucency)
+ : SkinSettingsUI(parent, name)
{
kcfg_skin->hide();
diff --git a/yakuake/src/skin_settings.h b/yakuake/src/skin_settings.h
index 94c111d..dc86368 100644
--- a/yakuake/src/skin_settings.h
+++ b/yakuake/src/skin_settings.h
@@ -25,7 +25,7 @@ class SkinSettings : public SkinSettingsUI
TQ_OBJECT
public:
- explicit SkinSettings(TQWidget* tqparent, const char* name=NULL, bool translucency = false);
+ explicit SkinSettings(TQWidget* parent, const char* name=NULL, bool translucency = false);
~SkinSettings();
diff --git a/yakuake/src/tab_bar.cpp b/yakuake/src/tab_bar.cpp
index d97cb9c..6a2965f 100644
--- a/yakuake/src/tab_bar.cpp
+++ b/yakuake/src/tab_bar.cpp
@@ -22,8 +22,8 @@
#include <kpopupmenu.h>
-TabBar::TabBar(TQWidget* tqparent, const char* name, bool translucency, const TQString & skin)
- : TranslucentWidget(tqparent, name, translucency)
+TabBar::TabBar(TQWidget* parent, const char* name, bool translucency, const TQString & skin)
+ : TranslucentWidget(parent, name, translucency)
{
loadSkin(skin);
diff --git a/yakuake/src/tab_bar.h b/yakuake/src/tab_bar.h
index d391347..36ecfad 100644
--- a/yakuake/src/tab_bar.h
+++ b/yakuake/src/tab_bar.h
@@ -36,7 +36,7 @@ class TabBar : public TranslucentWidget
TQ_OBJECT
public:
- explicit TabBar(TQWidget* tqparent = 0, const char* name = 0,
+ explicit TabBar(TQWidget* parent = 0, const char* name = 0,
bool translucency = false, const TQString& skin = "default");
~TabBar();
diff --git a/yakuake/src/tabbed_widget.cpp b/yakuake/src/tabbed_widget.cpp
index 9e01e00..7ac982f 100644
--- a/yakuake/src/tabbed_widget.cpp
+++ b/yakuake/src/tabbed_widget.cpp
@@ -24,8 +24,8 @@
#include <kiconloader.h>
-TabbedWidget::TabbedWidget(TQWidget* tqparent, const char* name, bool translucency)
- : TranslucentWidget(tqparent, name, translucency)
+TabbedWidget::TabbedWidget(TQWidget* parent, const char* name, bool translucency)
+ : TranslucentWidget(parent, name, translucency)
{
current_position = -1;
pressed = false;
@@ -68,26 +68,26 @@ void TabbedWidget::createContextMenu()
{
context_menu = new KPopupMenu();
- static_cast<KMainWindow*>(TQT_TQWIDGET(tqparent()->tqparent()))->actionCollection()->
+ static_cast<KMainWindow*>(TQT_TQWIDGET(parent()->parent()))->actionCollection()->
action("split_horizontally")->plug(context_menu);
- static_cast<KMainWindow*>(TQT_TQWIDGET(tqparent()->tqparent()))->actionCollection()->
+ static_cast<KMainWindow*>(TQT_TQWIDGET(parent()->parent()))->actionCollection()->
action("split_vertically")->plug(context_menu);
- static_cast<KMainWindow*>(TQT_TQWIDGET(tqparent()->tqparent()))->actionCollection()->
+ static_cast<KMainWindow*>(TQT_TQWIDGET(parent()->parent()))->actionCollection()->
action("remove_terminal")->plug(context_menu);
context_menu->insertSeparator();
- static_cast<KMainWindow*>(TQT_TQWIDGET(tqparent()->tqparent()))->actionCollection()->
+ static_cast<KMainWindow*>(TQT_TQWIDGET(parent()->parent()))->actionCollection()->
action("move_tab_left")->plug(context_menu);
- static_cast<KMainWindow*>(TQT_TQWIDGET(tqparent()->tqparent()))->actionCollection()->
+ static_cast<KMainWindow*>(TQT_TQWIDGET(parent()->parent()))->actionCollection()->
action("move_tab_right")->plug(context_menu);
context_menu->insertSeparator();
- static_cast<KMainWindow*>(TQT_TQWIDGET(tqparent()->tqparent()))->actionCollection()->
+ static_cast<KMainWindow*>(TQT_TQWIDGET(parent()->parent()))->actionCollection()->
action("edit_name")->plug(context_menu);
- static_cast<KMainWindow*>(TQT_TQWIDGET(tqparent()->tqparent()))->actionCollection()->
+ static_cast<KMainWindow*>(TQT_TQWIDGET(parent()->parent()))->actionCollection()->
action("remove_tab")->plug(context_menu);
}
@@ -452,16 +452,16 @@ void TabbedWidget::mousePressEvent(TQMouseEvent* e)
if (!context_menu) createContextMenu();
- static_cast<KMainWindow*>(TQT_TQWIDGET(tqparent()->tqparent()))->actionCollection()->
+ static_cast<KMainWindow*>(TQT_TQWIDGET(parent()->parent()))->actionCollection()->
action("move_tab_left")->setEnabled((position - 1 > 0));
- static_cast<KMainWindow*>(TQT_TQWIDGET(tqparent()->tqparent()))->actionCollection()->
+ static_cast<KMainWindow*>(TQT_TQWIDGET(parent()->parent()))->actionCollection()->
action("move_tab_right")->setEnabled((position - 1 < int(items.count()) - 1));
context_menu->exec(TQCursor::pos());
- static_cast<KMainWindow*>(TQT_TQWIDGET(tqparent()->tqparent()))->actionCollection()->
+ static_cast<KMainWindow*>(TQT_TQWIDGET(parent()->parent()))->actionCollection()->
action("move_tab_left")->setEnabled(true);
- static_cast<KMainWindow*>(TQT_TQWIDGET(tqparent()->tqparent()))->actionCollection()->
+ static_cast<KMainWindow*>(TQT_TQWIDGET(parent()->parent()))->actionCollection()->
action("move_tab_right")->setEnabled(true);
}
}
diff --git a/yakuake/src/tabbed_widget.h b/yakuake/src/tabbed_widget.h
index 591e437..4f92c81 100644
--- a/yakuake/src/tabbed_widget.h
+++ b/yakuake/src/tabbed_widget.h
@@ -39,7 +39,7 @@ class TabbedWidget : public TranslucentWidget
TQ_OBJECT
public:
- explicit TabbedWidget(TQWidget* tqparent = 0, const char* name = 0, bool translucency = false);
+ explicit TabbedWidget(TQWidget* parent = 0, const char* name = 0, bool translucency = false);
~TabbedWidget();
int pressedPosition();
diff --git a/yakuake/src/terminal.cpp b/yakuake/src/terminal.cpp
index f9ea737..d3a4f68 100644
--- a/yakuake/src/terminal.cpp
+++ b/yakuake/src/terminal.cpp
@@ -17,7 +17,7 @@
int Terminal::available_terminal_id = 0;
-Terminal::Terminal(TQWidget* tqparent, const char* name) : TQObject(tqparent, name)
+Terminal::Terminal(TQWidget* parent, const char* name) : TQObject(parent, name)
{
terminal_id = available_terminal_id;
available_terminal_id++;
@@ -33,7 +33,7 @@ Terminal::Terminal(TQWidget* tqparent, const char* name) : TQObject(tqparent, na
terminal_interface = NULL;
if ((factory = KLibLoader::self()->factory("libkonsolepart")) != NULL)
- terminal_part = (KParts::Part *) (factory->create(TQT_TQOBJECT(tqparent)));
+ terminal_part = (KParts::Part *) (factory->create(TQT_TQOBJECT(parent)));
if (terminal_part != NULL)
{
diff --git a/yakuake/src/terminal.h b/yakuake/src/terminal.h
index 745bedb..4c5db76 100644
--- a/yakuake/src/terminal.h
+++ b/yakuake/src/terminal.h
@@ -31,7 +31,7 @@ class Terminal : public TQObject
TQ_OBJECT
public:
- explicit Terminal(TQWidget* tqparent = 0, const char* name = 0);
+ explicit Terminal(TQWidget* parent = 0, const char* name = 0);
virtual ~Terminal();
int id() { return terminal_id; }
diff --git a/yakuake/src/terminal_focus_watcher.cpp b/yakuake/src/terminal_focus_watcher.cpp
index b21ba6d..e8d2030 100644
--- a/yakuake/src/terminal_focus_watcher.cpp
+++ b/yakuake/src/terminal_focus_watcher.cpp
@@ -14,8 +14,8 @@
#include "terminal_focus_watcher.moc"
-TerminalFocusWatcher::TerminalFocusWatcher(TQObject* tqparent, const char* name)
- : TQObject(tqparent, name)
+TerminalFocusWatcher::TerminalFocusWatcher(TQObject* parent, const char* name)
+ : TQObject(parent, name)
{
}
diff --git a/yakuake/src/terminal_focus_watcher.h b/yakuake/src/terminal_focus_watcher.h
index 1c725ca..17699b2 100644
--- a/yakuake/src/terminal_focus_watcher.h
+++ b/yakuake/src/terminal_focus_watcher.h
@@ -23,7 +23,7 @@ class TerminalFocusWatcher : public TQObject
TQ_OBJECT
public:
- explicit TerminalFocusWatcher(TQObject* tqparent = 0, const char* name = 0);
+ explicit TerminalFocusWatcher(TQObject* parent = 0, const char* name = 0);
virtual ~TerminalFocusWatcher();
virtual bool eventFilter (TQObject* watched, TQEvent* e);
diff --git a/yakuake/src/terminal_splitter.cpp b/yakuake/src/terminal_splitter.cpp
index 1c293da..f2fe4c6 100644
--- a/yakuake/src/terminal_splitter.cpp
+++ b/yakuake/src/terminal_splitter.cpp
@@ -16,8 +16,8 @@
#include <tqobjectlist.h>
-TerminalSplitter::TerminalSplitter(Qt::Orientation o, TQWidget* tqparent, const char* name)
- : TQSplitter(o, tqparent, name)
+TerminalSplitter::TerminalSplitter(Qt::Orientation o, TQWidget* parent, const char* name)
+ : TQSplitter(o, parent, name)
{
is_shutting_down = false;
}
diff --git a/yakuake/src/terminal_splitter.h b/yakuake/src/terminal_splitter.h
index 55ff7b6..9b045b8 100644
--- a/yakuake/src/terminal_splitter.h
+++ b/yakuake/src/terminal_splitter.h
@@ -23,7 +23,7 @@ class TerminalSplitter : public TQSplitter
TQ_OBJECT
public:
- explicit TerminalSplitter(Qt::Orientation o, TQWidget* tqparent=0, const char* name=0);
+ explicit TerminalSplitter(Qt::Orientation o, TQWidget* parent=0, const char* name=0);
~TerminalSplitter();
void focusNext();
diff --git a/yakuake/src/title_bar.cpp b/yakuake/src/title_bar.cpp
index 6fde45d..954f994 100644
--- a/yakuake/src/title_bar.cpp
+++ b/yakuake/src/title_bar.cpp
@@ -20,14 +20,14 @@
#include <klocale.h>
-TitleBar::TitleBar(TQWidget * tqparent, const char * name, const TQString & skin) : TQWidget(tqparent, name)
+TitleBar::TitleBar(TQWidget * parent, const char * name, const TQString & skin) : TQWidget(parent, name)
{
TQWhatsThis::add(this, i18n("The title bar displays the session title if available."));
loadSkin(skin);
- connect(focus_button, TQT_SIGNAL(toggled(bool)), tqparent, TQT_SLOT(slotSetFocusPolicy(bool)));
- connect(quit_button, TQT_SIGNAL(clicked()), tqparent, TQT_SLOT(close()));
+ connect(focus_button, TQT_SIGNAL(toggled(bool)), parent, TQT_SLOT(slotSetFocusPolicy(bool)));
+ connect(quit_button, TQT_SIGNAL(clicked()), parent, TQT_SLOT(close()));
}
TitleBar::~TitleBar()
@@ -39,7 +39,7 @@ TitleBar::~TitleBar()
TQRegion& TitleBar::getWidgetMask()
{
- return tqmask;
+ return mask;
}
void TitleBar::setTitleText(const TQString& title)
@@ -181,12 +181,12 @@ void TitleBar::setPixmaps(const TQString& skin)
void TitleBar::updateWidgetMask()
{
- TQRegion temp_tqmask;
+ TQRegion temp_mask;
- tqmask = TQRegion(*left_corner.tqmask());
- tqmask += TQRegion(TQRect(TQPoint(left_corner.width(), 0), TQPoint(width() - right_corner.width() - 1, height() - 1)));
+ mask = TQRegion(*left_corner.mask());
+ mask += TQRegion(TQRect(TQPoint(left_corner.width(), 0), TQPoint(width() - right_corner.width() - 1, height() - 1)));
- temp_tqmask = TQRegion(*right_corner.tqmask());
- temp_tqmask.translate(width() - right_corner.width(), 0);
- tqmask += temp_tqmask;
+ temp_mask = TQRegion(*right_corner.mask());
+ temp_mask.translate(width() - right_corner.width(), 0);
+ mask += temp_mask;
}
diff --git a/yakuake/src/title_bar.h b/yakuake/src/title_bar.h
index 52584d8..87e1687 100644
--- a/yakuake/src/title_bar.h
+++ b/yakuake/src/title_bar.h
@@ -38,7 +38,7 @@ class TitleBar : public TQWidget
TQ_OBJECT
public:
- explicit TitleBar(TQWidget * tqparent = 0, const char * name = 0, const TQString & skin = "default");
+ explicit TitleBar(TQWidget * parent = 0, const char * name = 0, const TQString & skin = "default");
~TitleBar();
TQRegion& getWidgetMask();
@@ -62,8 +62,8 @@ class TitleBar : public TQWidget
void loadSkin(const TQString& skin);
void updateWidgetMask();
- /* Widget's tqmask */
- TQRegion tqmask;
+ /* Widget's mask */
+ TQRegion mask;
/* Text properties */
TQString title_text;
diff --git a/yakuake/src/translucent_widget.cpp b/yakuake/src/translucent_widget.cpp
index aa87a9d..3201e37 100644
--- a/yakuake/src/translucent_widget.cpp
+++ b/yakuake/src/translucent_widget.cpp
@@ -16,7 +16,7 @@
#include <krootpixmap.h>
-TranslucentWidget::TranslucentWidget(TQWidget* tqparent, const char* name, bool translucency) : TQWidget(tqparent, name)
+TranslucentWidget::TranslucentWidget(TQWidget* parent, const char* name, bool translucency) : TQWidget(parent, name)
{
use_translucency = translucency;
diff --git a/yakuake/src/translucent_widget.h b/yakuake/src/translucent_widget.h
index e5899b2..991a254 100644
--- a/yakuake/src/translucent_widget.h
+++ b/yakuake/src/translucent_widget.h
@@ -26,7 +26,7 @@ class TranslucentWidget : public TQWidget
TQ_OBJECT
public:
- explicit TranslucentWidget(TQWidget* tqparent = 0, const char* name = 0, bool translucency = false);
+ explicit TranslucentWidget(TQWidget* parent = 0, const char* name = 0, bool translucency = false);
virtual ~TranslucentWidget();
diff --git a/yakuake/src/session.cpp b/yakuake/src/session.cpp
index 2a2bb23..eb3c294 100644
--- a/yakuake/src/session.cpp
+++ b/yakuake/src/session.cpp
@@ -23,7 +23,7 @@
int Session::available_session_id = 0;
-Session::Session(TQWidget* tqparent, SessionType type, const char* name) : TQObject(tqparent, name)
+Session::Session(TQWidget* parent, SessionType type, const char* name) : TQObject(parent, name)
{
session_id = available_session_id;
available_session_id++;
@@ -33,7 +33,7 @@ Session::Session(TQWidget* tqparent, SessionType type, const char* name) : TQObj
focus_watcher = new TerminalFocusWatcher(this);
connect(focus_watcher, TQT_SIGNAL(focusChanged()), this, TQT_SLOT(slotFocusChanged()));
- base_widget = new TerminalSplitter(Qt::Horizontal, tqparent, "base");
+ base_widget = new TerminalSplitter(Qt::Horizontal, parent, "base");
connect(base_widget, TQT_SIGNAL(destroyed()), this, TQT_SLOT(slotLastTerminalClosed()));
setenv("DCOP_YAKUAKE_SESSION", TQString::number(session_id).ascii(), 1);
@@ -305,7 +305,7 @@ void Session::split(TQWidget* active_terminal, Qt::Orientation o)
TerminalSplitter* splitter = static_cast<TerminalSplitter*>(active_terminal->parentWidget());
if (!splitter) return;
// If the tqparent splitter of this terminal has only this one child,
// add the new terminal to the same splitter, after resetting the
// splitter orientation as needed.
if (splitter->count() == 1)
@@ -323,7 +323,7 @@ void Session::split(TQWidget* active_terminal, Qt::Orientation o)
terminal->widget()->show();
}
// If the tqparent splitter of this terminal already has two tqchildren,
// add a new splitter to it and reparent the terminal to the new
// splitter.
else
@@ -351,9 +351,9 @@ void Session::split(TQWidget* active_terminal, Qt::Orientation o)
}
}
-Terminal* Session::addTerminal(TQWidget* tqparent)
+Terminal* Session::addTerminal(TQWidget* parent)
{
- Terminal* terminal = new Terminal(tqparent);
+ Terminal* terminal = new Terminal(parent);
terminals.insert(terminal->id(), terminal);
terminal_ids.insert(terminal->widget(), terminal->id());
@@ -305,7 +305,7 @@ void Session::split(TQWidget* active_terminal, Qt::Orientation o)
TerminalSplitter* splitter = static_cast<TerminalSplitter*>(active_terminal->parentWidget());
if (!splitter) return;
- // If the tqparent splitter of this terminal has only this one child,
+ // If the parent splitter of this terminal has only this one child,
// add the new terminal to the same splitter, after resetting the
// splitter orientation as needed.
@@ -323,7 +323,7 @@ void Session::split(TQWidget* active_terminal, Qt::Orientation o)
terminal->widget()->show();
}
- // If the tqparent splitter of this terminal already has two tqchildren,
+ // If the parent splitter of this terminal already has two tqchildren,
// add a new splitter to it and reparent the terminal to the new
// splitter.